@@ -3,7 +3,7 @@ package WWW::BackpackTF::User;
 use 5.014000;
 use strict;
 use warnings;
-our $VERSION = '0.001';
+our $VERSION = '0.001001';
 
 sub new{
 	my ($class, $content) = @_;
@@ -21,7 +21,7 @@ sub banned_backpack  { shift->{backpack_tf_banned} }
 sub banned_economy   { shift->{ban_economy} }
 sub banned_community { shift->{ban_community} }
 sub banned_vac       { shift->{ban_vac} }
-sub notifications    { shift->{notifications} }
+sub notifications    { shift->{notifications} // 0 }
 sub value            { shift->{backpack_value}->{shift // WWW::BackpackTF::TF2} }
 sub update           { shift->{backpack_update}->{shift // WWW::BackpackTF::TF2} }
 
@@ -141,7 +141,7 @@ Marius Gavrilescu, E<lt>marius@ieval.roE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014, 2015 by Marius Gavrilescu
+Copyright (C) 2014-2016 by Marius Gavrilescu
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.18.2 or,
